@@ -2,8 +2,6 @@
 use warnings;
 use strict;
 use 5.010000;
-binmode STDOUT, ':utf8';
-binmode STDIN, ':utf8';
 
 use Term::ReadLine::Tiny;
 
@@ -11,10 +9,8 @@ use FindBin qw( $RealBin );
 use lib $RealBin;
 use Data_Test_Readline;
 
-
-my $a_ref = Data_Test_Readline::return_test_data();
-
 my $tiny = Term::ReadLine::Tiny->new();
+my $a_ref = Data_Test_Readline::return_test_data();
 
 for my $ref ( @$a_ref ) {
     my $args  = $ref->{arguments};
